---
name: Bug report
about: Report a bug in pylint
---

<!--
  Hi there! Thank you for discovering and submitting an issue.

  Before you submit this, make sure that the issue doesn't already exist
  or if it is not closed.

  Is your issue fixed on the preview release?:
    pip install pylint astroid --pre -U
-->

### Steps to reproduce

<!--
Given a file `a.py`:
```python
# (Disable message unrelated to the bug)
# pylint: disable=missing-docstring,...

```

Given multiple files:
```
__init__.py
a.py
module\
    __init__.py
    b.py
    c.py
```
-->

### Current behavior

<!--
Result of `pylint a.py`:
```

```
-->

### Expected behavior

### pylint --version output

Result of `pylint --version` output:

```

```

<!--
Additional dependencies:
```
pandas==0.23.2
marshmallow==3.10.0
...
```
-->
